SamanthaNguyen has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/400126 )

Change subject: Replace deprecated ParserLimitReport hook with 
ParserLimitReportPrepare
......................................................................

Replace deprecated ParserLimitReport hook with ParserLimitReportPrepare

The ParserLimitReport hook has been deprecated since MediaWiki 1.22,
so use the suggested ParserLimitReportPrepare hook instead.

Bug: T183652
Change-Id: I97c03b5f0d3c2bbda39a2d58dfa48a13f1f8fc46
---
M extension.json
M includes/PollNY.hooks.php
2 files changed, 6 insertions(+), 6 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/PollNY 
refs/changes/26/400126/1

diff --git a/extension.json b/extension.json
index d1f2d85..d40bcc3 100644
--- a/extension.json
+++ b/extension.json
@@ -1,6 +1,6 @@
 {
        "name": "PollNY",
-       "version": "3.4.3",
+       "version": "3.4.4",
        "author": [
                "Aaron Wright",
                "David Pean",
diff --git a/includes/PollNY.hooks.php b/includes/PollNY.hooks.php
index d7d0c59..7ae7f95 100644
--- a/includes/PollNY.hooks.php
+++ b/includes/PollNY.hooks.php
@@ -108,7 +108,7 @@
 
                        // We don't want caching here, it'll only cause 
problems...
                        $wgOut->enableClientCache( false );
-                       $wgHooks['ParserLimitReport'][] = 
'PollNYHooks::markUncacheable';
+                       $wgHooks['ParserLimitReportPrepare'][] = 
'PollNYHooks::onParserLimitReportPrepare';
 
                        // Prevents editing of polls
                        if( $wgRequest->getVal( 'action' ) == 'edit' ) {
@@ -138,11 +138,11 @@
        /**
         * Mark page as uncacheable
         *
         * @param $parser Parser object
         * @param $limitReport String: unused
         * @return Boolean: true
         */
-       public static function markUncacheable( $parser, &$limitReport ) {
+       public static function onParserLimitReportPrepare( $parser, $output ) {
                $parser->disableCache();
                return true;
        }
@@ -138,11 +138,11 @@
         * Mark page as uncacheable
         *
-        * @param $parser Parser object
-        * @param $limitReport String: unused
-        * @return Boolean: true
+        * @param Parser $parser
+        * @param ParserOutput $limitReport
+        * @return bool true
         */

-- 
To view, visit https://gerrit.wikimedia.org/r/400126
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I97c03b5f0d3c2bbda39a2d58dfa48a13f1f8fc46
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/PollNY
Gerrit-Branch: master
Gerrit-Owner: SamanthaNguyen <samanthanguyen1...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to